
% this generates sample R2s from regressions of returns on p/d at
% 1-20-quarter horizons. 
% note that getting the average level of returns right doesn't matter

% the hard-coded numbers here come from the "table 1" sheet in
% tables.9.xlsx.

clear all

theta=.99021;
phi=.99^.25;
gamma=4.806;
delta=.95^.25;
beta=phi;
k0=(gamma-1)*(beta-theta)/(1-delta*beta);

awd=.324917541;
k0 = (gamma-1)*awd/(1-delta*awd);

T=100000;

dc=randn(T,1)*.01465;

draws=randn(T,1)*.0147;
dc_wc=0*dc;
for i=2:T
    dc_wc(i) = beta*dc_wc(i-1) + draws(i) - theta*draws(i-1);
end


pd=zeros(T+1,1);
rf=pd;
rf_wc=pd;
pd_wc=pd;

for t=2:T+1
    pd(t)=theta*pd(t-1)+(delta*k0+gamma-1)*(beta-theta)*dc(t-1)/(1-delta*beta);
    rf(t) = theta*rf(t-1) + (beta-theta)*dc(t-1);
    
    pd_wc(t)=theta*pd_wc(t-1)+(delta*k0+gamma-1)*(beta-theta)*dc_wc(t-1)/(1-delta*beta);
    rf_wc(t) = theta*rf_wc(t-1) + (beta-theta)*dc_wc(t-1);
end


r=delta*pd(2:end)+gamma*dc - pd(1:end-1) - rf(1:end-1);
r_wc=delta*pd_wc(2:end)+gamma*dc_wc - pd_wc(1:end-1) - rf_wc(1:end-1);


r2=zeros(1000,120);
r2_wc=zeros(1000,120);

Nsamp=90*4;

for i=1:1000
    if floor(i/100)==i/100; disp(i); end
    start=ceil(rand*(T-Nsamp-20));
    rsamp=r(start:start+Nsamp);
    pdsamp=pd(start:start+Nsamp+1);
    
    rsamp_wc=r_wc(start:start+Nsamp);
    pdsamp_wc=pd_wc(start:start+Nsamp+1);
    
    for hor=[1:120]
        rh=rsamp(1:end+1-hor);
        rh_wc=rsamp_wc(1:end+1-hor);
        for count=2:hor
            rh=rh+rsamp(count:end+count-hor);
            rh_wc=rh_wc+rsamp_wc(count:end+count-hor);
        end
        r2(i,hor)=corr(rh,pdsamp(1:end-hor))^2;
        r2_wc(i,hor)=corr(rh_wc,pdsamp_wc(1:end-hor))^2;
    end
end

prctile(r2(:,1:40),[25;50;75])'


% for beta=.98^.25, need gamma=5.05 and lambda=22.62



% empirical R2:
clear
load crspret
% R' = (P'+D')/P
% Rx'=P'/P
% R'-Rx' = D'/P
% (R'-Rx')/Rx' = D'/P'

dp=((retd-retx)./(1+retx));


dp=log(dp(3:end)+dp(2:end-1)+dp(1:end-2));

% dp2=dp(12:end);
% for i=1:11
%     dp2=dp2+dp(12-i:end-i);
% end
% dp=log(dp2);


retd=log(1+retd(3:end));

for hor=[3:3:120]
    rh=retd(1:end+1-hor);
    for count=2:hor
        rh=rh+retd(count:end+count-hor);
    end
    r2(hor/3)=corr(rh(2:3:end),dp(1:3:end-hor))^2;
end

disp(r2')








